@@ -3,14 +3,20 @@ from pdlpy.distribution import Distribution
 
 class Bernoulli(Distribution):
     """
-    Discrete probability distribution of a random variable X which takes either value 1 or 0
+    Discrete probability distribution of a random variable X
+    which either takes the value 1 or 0 in a single yes-no
+    experiment
     """
 
     def __init__(self, p: float):
         """
         Parameters
-        p: the probability of positive outcome of an experiment
+        p: the probability of success
         """
+
+        if p < 0 or p > 1:
+            raise ValueError("p must be in the range [0, 1]")
+
         self._p = p
         self._mean = p
         self._median = 0 if p < 0.5 else 1
@@ -33,11 +39,15 @@ class Bernoulli(Distribution):
         Probability Mass Function
 
         Parameters
-        x: a value of the random variable X
+        x: the value of the random variable X
 
         Returns
-        the probability that X will take a value exactly equal to x
+        The probability that X will take a value exactly equal to x
         """
+
+        if x not in {0, 1}:
+            raise ValueError("x must be either 0 or 1")
+
         if x == 0:
             return 1.0 - self._p
         else:
@@ -48,11 +58,15 @@ class Bernoulli(Distribution):
         Cumulative Distribution Function
 
         Parameters
-        x: a value of the random variable X
+        x: the value of the random variable X
 
         Returns
-        the probability that X will take a value less than or equal to x
+        The probability that X will take a value less than or equal to x
         """
+
+        if x not in {0, 1}:
+            raise ValueError("x must be either 0 or 1")
+
         if x == 0:
             return 1.0 - self._p
         else:
