@@ -1,10 +1,12 @@
 from pdlpy.distribution import Distribution
-from pdlpy.math import floor, ncr
+from pdlpy.math import ncr
 
 
 class Hypergeometric(Distribution):
     """
-    Discrete probability distribution that describes the probability of successes in draws from a finite test set
+    Discrete probability distribution of a random variable X
+    that describes the probability of successes in draws
+    from a finite test set
     """
 
     def __init__(self, n: int, N: int, M: int):
@@ -14,6 +16,16 @@ class Hypergeometric(Distribution):
         N: the size of the test set
         M: the number of successes
         """
+
+        if N < 0:
+            raise ValueError("N must be greater than or equal to 0")
+
+        if n < 0 or n > N:
+            raise ValueError("n must be in the range [0, N]")
+
+        if M < 0 or M > N:
+            raise ValueError("M must be in the range [0, N]")
+
         self._n = n
         self._N = N
         self._M = M
@@ -40,11 +52,15 @@ class Hypergeometric(Distribution):
         Probability Mass Function
 
         Parameters
-        x: a value of the random variable X
+        x: the value of the random variable X
 
         Returns
-        the probability that X will take a value exactly equal to x
+        The probability that X will take a value exactly equal to x
         """
+
+        if x < 0 or x > self._n:
+            raise ValueError("x must be in the range [0, n]")
+
         return (
             ncr(self._M, x)
             * ncr(self._N - self._M, self._n - x)
@@ -56,11 +72,15 @@ class Hypergeometric(Distribution):
         Cumulative Distribution Function
 
         Parameters
-        x: a value of the random variable X
+        x: the value of the random variable X
 
         Returns
-        the probability that X will take a value less than or equal to x
+        The probability that X will take a value less than or equal to x
         """
+
+        if x < 0 or x > self._n:
+            raise ValueError("x must be in the range [0, n]")
+
         if x == 0:
             return self.pmf(0)
         else:
